@@ -3,8 +3,7 @@ package machine
 import (
 	"testing"
 
-	machinev1 "github.com/openshift/cluster-api/pkg/apis/machine/v1beta1"
-	capifake "github.com/openshift/cluster-api/pkg/client/clientset_generated/clientset/fake"
+	machinev1 "github.com/openshift/machine-api-operator/pkg/apis/machine/v1beta1"
 	"k8s.io/client-go/kubernetes/scheme"
 	"k8s.io/client-go/tools/record"
 	"sigs.k8s.io/controller-runtime/pkg/client/fake"
@@ -20,10 +19,8 @@ func TestActuatorCreate(t *testing.T) {
 	recorder := &record.FakeRecorder{
 		Events: eventsChannel,
 	}
-	cs := capifake.NewSimpleClientset()
 	// Initialize machine actuator.
 	machineActuator := NewActuator(ActuatorParams{
-		MachineClient: cs.MachineV1beta1(),
 		CoreClient:    fake.NewFakeClient(),
 		EventRecorder: recorder,
 	})
